From: Sylvain Munaut <tnt@246tNt•com>
To: Andrew Morton <akpm@osdl•org>
Cc: Tom Rini <trini@kernel•crashing.org>,
Sylvain Munaut <tnt@246tNt•com>,
Linux PPC Embedded <linuxppc-embedded@ozlabs•org>
Subject: [PATCH 4/9] ppc32: Fix static IO mapping for Freescale MPC52xx
Date: Tue, 20 Dec 2005 21:42:02 +0100 (CET) [thread overview]
Message-ID: <4.20051220_213752_1ebc_tnt@patchsend.246tNt.com> (raw)
In-Reply-To: <0.20051220_213752_1ebc_tnt@patchsend.246tNt.com>
ppc32: Fix static IO mapping for Freescale MPC52xx
The current iomapping used MBAR_SIZE for the size argument
of io_block_mapping, resulting in a call to setbat with a
size argument of 64k which is invalid.
This patch correct this and maps the whole 0xf0000000->0xffffffff
range so that devices on the local bus are also included in
the BAT mapping.
Thanks to Bernhard Kuhn from Metrowerks for pointing this out.
Signed-off-by: Sylvain Munaut <tnt@246tNt•com>
---
commit ae62fed2708efa333d41f7b36893e5fdbd0f6730
tree a1a4da53edb2f235be6658558eeb606a0b2580e9
parent 1661f915e8bd58e52fe3326e038efe74068702e0
author Sylvain Munaut <tnt@246tNt•com> Sun, 18 Dec 2005 11:13:15 +0100
committer Sylvain Munaut <tnt@246tNt•com> Sun, 18 Dec 2005 11:13:15 +0100
arch/ppc/syslib/mpc52xx_setup.c | 6 ++++--
1 files changed, 4 insertions(+), 2 deletions(-)
diff --git a/arch/ppc/syslib/mpc52xx_setup.c b/arch/ppc/syslib/mpc52xx_setup.c
index bb23745..a4a4b02 100644
--- a/arch/ppc/syslib/mpc52xx_setup.c
+++ b/arch/ppc/syslib/mpc52xx_setup.c
@@ -84,9 +84,11 @@ mpc52xx_set_bat(void)
void __init
mpc52xx_map_io(void)
{
- /* Here we only map the MBAR */
+ /* Here we map the MBAR and the whole upper zone. MBAR is only
+ 64k but we can't map only 64k with BATs. Map the whole
+ 0xf0000000 range is ok and helps eventual lpb devices placed there */
io_block_mapping(
- MPC52xx_MBAR_VIRT, MPC52xx_MBAR, MPC52xx_MBAR_SIZE, _PAGE_IO);
+ MPC52xx_MBAR_VIRT, MPC52xx_MBAR, 0x10000000, _PAGE_IO);
}
next prev parent reply other threads:[~2005-12-20 20:42 UTC|newest]
Thread overview: 12+ messages / expand[flat|nested] mbox.gz Atom feed top
2005-12-20 20:40 [PATCH 0/9] Some Freescale MPC52xx related updates Sylvain Munaut
2005-12-20 20:40 ` [PATCH 1/9] ppc32: Remove useless file arch/ppc/platforms/mpc5200.c Sylvain Munaut
2005-12-20 20:41 ` [PATCH 2/9] ppc32/serial: Fix compiler errors with GCC 4.x in mpc52xx_uart.c Sylvain Munaut
2005-12-20 20:41 ` [PATCH 3/9] ppc32/serial: Change mpc52xx_uart.c to use the Low Density Serial port major Sylvain Munaut
2005-12-20 20:42 ` Sylvain Munaut [this message]
2005-12-20 20:42 ` [PATCH 5/9] ppc32: Modify Freescale MPC52xx IRQ mapping to _not_ use irq 0 Sylvain Munaut
2005-12-20 20:43 ` [PATCH 6/9] ppc32: Remove __init qualifier from mpc52xx pci resources fixups Sylvain Munaut
2005-12-20 20:43 ` [PATCH 7/9] ppc32: Fix MPC52xx configuration space access Sylvain Munaut
2005-12-20 20:44 ` [PATCH 8/9] ppc32: Fix MPC52xx PCI init in cas the bootloader didn't do it Sylvain Munaut
2005-12-20 20:44 ` [PATCH 9/9] ppc32: Allows compilation of a MPC52xx kernel without PCI Sylvain Munaut
2005-12-20 20:54 ` [PATCH 0/9] Some Freescale MPC52xx related updates Kumar Gala
2005-12-20 21:36 ` Sylvain Munaut
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4.20051220_213752_1ebc_tnt@patchsend.246tNt.com \
--to=tnt@246tnt$(echo .)com \
--cc=akpm@osdl$(echo .)org \
--cc=linuxppc-embedded@ozlabs$(echo .)org \
--cc=trini@kernel$(echo .)crashing.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox